
#ifndef __LIBGNOMENU_MENUBAR_H__
#define __LIBGNOMENU_MENUBAR_H__

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <stdlib.h>
#include <string.h>
#include <libgnomenu/interface-shell.h>
#include <libgnomenu/helper.h>
#include <libgnomenu/menuitem.h>
#include <libgnomenu/interface-item.h>

G_BEGIN_DECLS


#define GNOMENU_TYPE_BACKGROUND (gnomenu_background_get_type ())
#define GNOMENU_BACKGROUND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOMENU_TYPE_BACKGROUND, GnomenuBackground))
#define GNOMENU_BACKGROUND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOMENU_TYPE_BACKGROUND, GnomenuBackgroundClass))
#define GNOMENU_IS_BACKGROUND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOMENU_TYPE_BACKGROUND))
#define GNOMENU_IS_BACKGROUND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOMENU_TYPE_BACKGROUND))
#define GNOMENU_BACKGROUND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOMENU_TYPE_BACKGROUND, GnomenuBackgroundClass))

typedef struct _GnomenuBackground GnomenuBackground;
typedef struct _GnomenuBackgroundClass GnomenuBackgroundClass;
typedef struct _GnomenuBackgroundPrivate GnomenuBackgroundPrivate;
typedef struct _GnomenuParamSpecBackground GnomenuParamSpecBackground;

#define GNOMENU_TYPE_MENU_BAR (gnomenu_menu_bar_get_type ())
#define GNOMENU_MENU_BAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOMENU_TYPE_MENU_BAR, GnomenuMenuBar))
#define GNOMENU_MENU_BAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOMENU_TYPE_MENU_BAR, GnomenuMenuBarClass))
#define GNOMENU_IS_MENU_BAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOMENU_TYPE_MENU_BAR))
#define GNOMENU_IS_MENU_BAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOMENU_TYPE_MENU_BAR))
#define GNOMENU_MENU_BAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOMENU_TYPE_MENU_BAR, GnomenuMenuBarClass))

typedef struct _GnomenuMenuBar GnomenuMenuBar;
typedef struct _GnomenuMenuBarClass GnomenuMenuBarClass;
typedef struct _GnomenuMenuBarPrivate GnomenuMenuBarPrivate;

/**
 *
 * This structure is used to represent a 'background' passed from
 * the panel library.
 * 
 */
struct _GnomenuBackground {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GnomenuBackgroundPrivate * priv;
	GnomenuBackgroundType type;
	GdkPixmap* pixmap;
	GdkColor color;
	gint offset_x;
	gint offset_y;
};

struct _GnomenuBackgroundClass {
	GTypeClass parent_class;
	void (*finalize) (GnomenuBackground *self);
};

struct _GnomenuParamSpecBackground {
	GParamSpec parent_instance;
};

/**
 * A fancy menubar used by GlobalMenu.PanelApplet;
 * Not the same as Gtk.MenuBar, Gnomenu.MenuBar also
 * explicityly acts as the toplevel menubar of
 * its logical descents.
 *
 * It supports changing the background,
 * getting an xml representation of the overflown items,
 * changing the text gravity,
 * looking up item (and subitems) by path.
 */
struct _GnomenuMenuBar {
	GtkMenuBar parent_instance;
	GnomenuMenuBarPrivate * priv;
};

struct _GnomenuMenuBarClass {
	GtkMenuBarClass parent_class;
};


GnomenuBackground* gnomenu_background_clone (GnomenuBackground* self);
GnomenuBackground* gnomenu_background_construct (GType object_type);
GnomenuBackground* gnomenu_background_new (void);
GParamSpec* gnomenu_param_spec_background (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
gpointer gnomenu_value_get_background (const GValue* value);
void gnomenu_value_set_background (GValue* value, gpointer v_object);
GType gnomenu_background_get_type (void);
gpointer gnomenu_background_ref (gpointer instance);
void gnomenu_background_unref (gpointer instance);
GnomenuMenuBar* gnomenu_menu_bar_construct (GType object_type);
GnomenuMenuBar* gnomenu_menu_bar_new (void);
GnomenuMenuItem* gnomenu_menu_bar_get (GnomenuMenuBar* self, const char* path);
char* gnomenu_menu_bar_create_overflown_menu (GnomenuMenuBar* self);
GnomenuBackground* gnomenu_menu_bar_get_background (GnomenuMenuBar* self);
void gnomenu_menu_bar_set_background (GnomenuMenuBar* self, GnomenuBackground* value);
GnomenuGravity gnomenu_menu_bar_get_gravity (GnomenuMenuBar* self);
void gnomenu_menu_bar_set_gravity (GnomenuMenuBar* self, GnomenuGravity value);
gboolean gnomenu_menu_bar_get_overflown (GnomenuMenuBar* self);
gint gnomenu_menu_bar_get_min_length (GnomenuMenuBar* self);
void gnomenu_menu_bar_set_min_length (GnomenuMenuBar* self, gint value);
GType gnomenu_menu_bar_get_type (void);


G_END_DECLS

#endif
