
#ifndef __LIBGNOMENU_MENUITEM_H__
#define __LIBGNOMENU_MENUITEM_H__

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <stdlib.h>
#include <string.h>
#include <libgnomenu/interface-item.h>
#include <libgnomenu/helper.h>
#include <libgnomenu/interface-shell.h>

G_BEGIN_DECLS


#define GNOMENU_TYPE_MENU_ITEM (gnomenu_menu_item_get_type ())
#define GNOMENU_MENU_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOMENU_TYPE_MENU_ITEM, GnomenuMenuItem))
#define GNOMENU_MENU_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOMENU_TYPE_MENU_ITEM, GnomenuMenuItemClass))
#define GNOMENU_IS_MENU_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOMENU_TYPE_MENU_ITEM))
#define GNOMENU_IS_MENU_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOMENU_TYPE_MENU_ITEM))
#define GNOMENU_MENU_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOMENU_TYPE_MENU_ITEM, GnomenuMenuItemClass))

typedef struct _GnomenuMenuItem GnomenuMenuItem;
typedef struct _GnomenuMenuItemClass GnomenuMenuItemClass;
typedef struct _GnomenuMenuItemPrivate GnomenuMenuItemPrivate;

/**
 * fancy menu item used by GlobalMenu.PanelApplet
 *
 * Difference with Gtk.MenuItem:
 *
 * The various derived XXXMenuItem types are integrated
 * into Gnomenu.MenuItem to allow easier tranformation
 * from XML representation to Widgets.
 *
 * label and image are directly set on the MenuItem.
 * each item has an id,
 * associated with a position(after attached to a MenuShell)
 *
 * MenuItem also holds a back-reference to the toplevel 
 * menu bar. When an item is activated, the activated signal
 * on the menu bar is also invoked.
 * 
 */
struct _GnomenuMenuItem {
	GtkMenuItem parent_instance;
	GnomenuMenuItemPrivate * priv;
};

struct _GnomenuMenuItemClass {
	GtkMenuItemClass parent_class;
};


GnomenuMenuItem* gnomenu_menu_item_construct (GType object_type);
GnomenuMenuItem* gnomenu_menu_item_new (void);
GnomenuGravity gnomenu_menu_item_get_gravity (GnomenuMenuItem* self);
void gnomenu_menu_item_set_gravity (GnomenuMenuItem* self, GnomenuGravity value);
gboolean gnomenu_menu_item_get_truncated (GnomenuMenuItem* self);
void gnomenu_menu_item_set_truncated (GnomenuMenuItem* self, gboolean value);
GtkImage* gnomenu_menu_item_get_image (GnomenuMenuItem* self);
GType gnomenu_menu_item_get_type (void);


G_END_DECLS

#endif
