
#ifndef __LIBGNOMENU_WINDOW_H__
#define __LIBGNOMENU_WINDOW_H__

#include <glib.h>
#include <glib-object.h>
#include <gdk/gdk.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>

G_BEGIN_DECLS


#define GNOMENU_TYPE_WINDOW (gnomenu_window_get_type ())
#define GNOMENU_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOMENU_TYPE_WINDOW, GnomenuWindow))
#define GNOMENU_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOMENU_TYPE_WINDOW, GnomenuWindowClass))
#define GNOMENU_IS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOMENU_TYPE_WINDOW))
#define GNOMENU_IS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOMENU_TYPE_WINDOW))
#define GNOMENU_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOMENU_TYPE_WINDOW, GnomenuWindowClass))

typedef struct _GnomenuWindow GnomenuWindow;
typedef struct _GnomenuWindowClass GnomenuWindowClass;
typedef struct _GnomenuWindowPrivate GnomenuWindowPrivate;

/**
 * The Window widget extends Gtk.Window widget.
 *
 * The Window widget is capable of wrapping a Gdk.Window
 * or a is_foreign native window.
 *
 * It adds methods to bind any string as a property of
 * the underlining Gdk.Window.
 *
 * It emits property-notify-event signal when any properties of the underlineing Gdk.Window
 * has changed.
 *
 * As convenient wrappers,
 * it also addes the menu-context property and menu-event signal.
 *
 */
struct _GnomenuWindow {
	GObject parent_instance;
	GnomenuWindowPrivate * priv;
};

struct _GnomenuWindowClass {
	GObjectClass parent_class;
};


GnomenuWindow* gnomenu_window_construct (GType object_type, GdkWindow* window);
GnomenuWindow* gnomenu_window_new (GdkWindow* window);
GnomenuWindow* gnomenu_window_foreign_new (gulong xid);
void gnomenu_window_set_key_widget (GnomenuWindow* self, GtkWidget* widget);
char* gnomenu_window_get (GnomenuWindow* self, const char* property_name);
void gnomenu_window_set (GnomenuWindow* self, const char* property_name, const char* value);
char* gnomenu_window_get_by_atom (GnomenuWindow* self, GdkAtom atom);
void gnomenu_window_set_by_atom (GnomenuWindow* self, GdkAtom atom, const char* value);
void gnomenu_window_emit_menu_event (GnomenuWindow* self, const char* path);
gboolean gnomenu_window_grab_key (GnomenuWindow* self, guint keyval, GdkModifierType state);
gboolean gnomenu_window_ungrab_key (GnomenuWindow* self, guint keyval, GdkModifierType state);
GdkWindow* gnomenu_window_get_window (GnomenuWindow* self);
void gnomenu_window_set_window (GnomenuWindow* self, GdkWindow* value);
const char* gnomenu_window_get_menu_context (GnomenuWindow* self);
void gnomenu_window_set_menu_context (GnomenuWindow* self, const char* value);
GType gnomenu_window_get_type (void);


G_END_DECLS

#endif
